@@ -364,9 +364,20 @@ od_get_active_server (ObjectDirectory    *od,
 			break;
 		}
         }
-	if (retval != CORBA_OBJECT_NIL &&
-	    !CORBA_Object_non_existent (retval, NULL))
-		return CORBA_Object_duplicate (retval, NULL);
+	if (retval != CORBA_OBJECT_NIL) {
+                gboolean non_existent;
+                ServerLockState state;
+
+                /* With dead objects, this path can cause lengthy
+                   re-connection attempts, blocking all other
+                   activation, so drop the lock. g#512520 */
+                state = server_lock_drop();
+                non_existent = CORBA_Object_non_existent (retval, NULL);
+                server_lock_resume (state);
+
+                if (!non_existent)
+                        return CORBA_Object_duplicate (retval, NULL);
+        }
 
 	return CORBA_OBJECT_NIL;
 }
@@ -676,7 +687,7 @@ prune_dead_servers (gpointer key,
 }
 
 static gboolean
-as_rescan (gpointer data)
+as_rescan (gpointer is_idle_rescan)
 {
         ObjectDirectory *od;
         static gboolean in_rescan = FALSE;
@@ -684,6 +695,9 @@ as_rescan (gpointer data)
 
         server_lock ();
 
+        if (GPOINTER_TO_UINT (is_idle_rescan))
+                idle_id = 0;
+
         if (!(od = main_dir)) { /* shutting down */
                 server_unlock ();
                 return FALSE;
@@ -692,7 +706,7 @@ as_rescan (gpointer data)
         /* We tend to get a lot of 'broken' callbacks at once */
         if (in_rescan) {
                 if (!idle_id)
-                        idle_id = g_idle_add (as_rescan, NULL);
+                        idle_id = g_timeout_add (100, as_rescan, GUINT_TO_POINTER (1));
                 server_unlock ();
                 return FALSE;
         }
